@@ -2,9 +2,10 @@
 #define ERIS_AVATAR_H
 
 #include <Eris/Types.h>
-#include <Atlas/Objects/ObjectsFwd.h>
 #include <Eris/EntityRef.h>
 
+#include <Atlas/Objects/ObjectsFwd.h>
+
 #include <wfmath/point.h>
 #include <wfmath/vector.h>
 #include <wfmath/quaternion.h>
@@ -14,10 +15,6 @@
 #include <sigc++/signal.h>
 #include <sigc++/connection.h>
 
-#include <string>
-#include <map>
-#include <vector>
-
 namespace Eris
 {
 
@@ -175,7 +172,6 @@ protected:
 
     IGRouter* m_router;
     View* m_view;
-    TypeInfoArray m_useOps;
 
     EntityRef m_wielded;
 
