@@ -73,6 +73,10 @@ int Connection::disconnect()
         return -1;
     }
 
+    // This assert means that this function will always return early below
+    // where m_lock is checked. m_lock seems to be used by Account to prevent
+    // disconnecting when something is pending.
+    // FIXME Look into this.
     assert(m_lock == 0);
 
     // this is a soft disconnect; it will give people a chance to do tear down and so on
@@ -96,8 +100,9 @@ int Connection::disconnect()
 
 void Connection::gotData(PollData &data)
 {
-    if (!_stream || !data.isReady(_stream))
+    if (!_stream || !data.isReady(_stream)) {
         return;
+    }
 
     if (_status == DISCONNECTED) {
         error() << "Got data on a disconnected stream";
@@ -122,8 +127,7 @@ void Connection::gotData(PollData &data)
 
 void Connection::send(const Atlas::Objects::Root &obj)
 {
-    if ((_status != CONNECTED) && (_status != DISCONNECTING))
-    {
+    if ((_status != CONNECTED) && (_status != DISCONNECTING)) {
         error() << "called send on closed connection";
         return;
     }
