@@ -1,8 +1,10 @@
 #include <Eris/Types.h>
 
 #include <Eris/PollDefault.h>
-#include <Eris/Timeout.h>
 #include <Eris/Exceptions.h>
+#include <Eris/DeleteLater.h>
+#include <Eris/Log.h>
+#include <Eris/TimedEventService.h>
 
 #include <skstream/skstream.h>
 
@@ -59,8 +61,8 @@ PollDataDefault::PollDataDefault(const PollDefault::MapType& str,
 	for(_iter I = str2->begin(); I != str2->end(); ++I) {
 #endif
 		SOCKET_TYPE fd = I->first->getSocket();
-		if(fd == INVALID_SOCKET)
-                	continue;
+		if(fd == INVALID_SOCKET) continue;
+        
 		got_data = true;
 		if(I->second & Poll::READ)
 			FD_SET(fd, &reading);
@@ -70,15 +72,14 @@ PollDataDefault::PollDataDefault(const PollDefault::MapType& str,
 			maxfd = fd;
 	}
 
-	if(!got_data)
-		return;
+	if (!got_data) return;
 
 	struct timeval timeout = {msec_timeout / 1000, (msec_timeout % 1000) * 1000};
 	int retval = select(maxfd+1, &reading, &writing, NULL, &timeout);
-	if (retval < 0)
-		// FIXME - is an error from select fatal or not? At present I think yes,
-		// but I'm sort of open to persuasion on this matter.
-		throw InvalidOperation("Error at PollDefault::Poll() doing select()");
+	if (retval < 0) {
+        warning() << "select() returned error: " << retval;
+        got_data = false;
+    }
 
 	got_data = (retval != 0);
 }
@@ -100,7 +101,7 @@ void PollDefault::doPoll(unsigned long timeout)
     PollDataDefault data(_streams, got_data, timeout);
 
     if(got_data)
-	emit(data);
+	Ready.emit(data);
 }
 
 void PollDefault::poll(unsigned long timeout)
@@ -122,7 +123,7 @@ void PollDefault::poll(unsigned long timeout)
     while(wait_time < timeout) {
       inst.doPoll(wait_time);
       timeout -= wait_time;
-      wait_time = Timeout::pollAll();
+      wait_time = TimedEventService::instance()->tick();
       if(inst.new_timeout_) {
         // Added a timeout, the time until it must be called
         // may be shorter than wait_time
@@ -130,15 +131,16 @@ void PollDefault::poll(unsigned long timeout)
         inst.new_timeout_ = false;
       }
     }
-  
+
     inst.doPoll(timeout);
-    Timeout::pollAll();
-  
+    TimedEventService::instance()->tick();
+    execDeleteLaters();
+
     // We're done, turn off the reentrancy prevention flag
     assert(already_polling);
     already_polling = false;
   }
-  catch (...) {
+  catch(...) {
     already_polling = false;
     throw;
   }
