@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Account_unittest.cpp,v 1.12 2007-10-24 17:13:52 alriddoch Exp $
+// $Id$
 
 #include <Eris/Account.h>
 
@@ -28,9 +28,12 @@
 
 #include <Atlas/Objects/Anonymous.h>
 #include <Atlas/Objects/Entity.h>
+#include <Atlas/Objects/Operation.h>
 
 #include <sigc++/adaptors/hide.h>
 
+#include <iostream>
+
 class TestConnection : public Eris::Connection {
   public:
     TestConnection(const std::string & name, const std::string & host,
